# HPL - The HAROS Property Specification Language

This directory contains various documentation files on the HPL project.

For more information on the language itself, see [Language Overview](./lang.md).

For a complete reference of the language's syntax, see [Language Syntax](./syntax.md).

For a formalization of the language's semantics, see [Language Semantics](./semantics.md).

For a complete reference on the language's Python representation, see [AST](./py-ast.md).
